<?php
/**
* @version      mod_scorpion_buienradar.php - 24/01/2024
* @author       Edwin Witlox $
* @copyright    (C) Scorpion Computers and Software
* @license      http://www.gnu.org/copyleft/gpl.html GNU/GPL
* @email        info@scorpioncomputers.nl
*/

// no direct access
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;

// First we get the parameters from the module
$document = Factory::getDocument();
$baseURL = Uri::root(true);
$LocationPosition = $params->get( 'LocationPosition' );
$LocationAlignment = $params->get( 'LocationAlignment' );
$LocationText = $params->get( 'LocationText' );
$Breedte = $params->get( 'Breedte' );
$Hoogte = $params->get( 'Hoogte' );
$Latitude = $params->get( 'Latitude' );
$Longitude = $params->get( 'Longitude' );
$Zoom = $params->get( 'Zoom' );
$Plaats = $params->get( 'Plaats' );
$Kaartgrootte = $params->get( 'Kaartgrootte' );
$Tijdsweergave = $params->get( 'Tijdsweergave' );
$ShowDotOrImage = $params->get( 'ShowDotOrImage' );
$DotColor = $params->get( 'DotColor', '#F48F25' );
$DotSize = $params->get( 'DotSize' );
$IconFile = $params->get( 'IconFile' );
$IconHeight = $params->get( 'IconHeight', '36' );
$IconWidth = $params->get( 'IconWidth', '36' );

// Add the CSS file from this module
$urlCSS = $baseURL.'/modules/mod_scorpion_buienradar/mod_scorpion_buienradar.css';
$document->addStyleSheet($urlCSS);

// If we need to show the dot, some extra styling is needed
if($ShowDotOrImage == '1') {
    // We create extra styling to overrule the values in the css files
    $halfSize = ((int)$DotSize) / 2;
    $extraStyle = '.scs-buienradar-pointer { background-color: '.$DotColor.' !important; }'."\r\n";
    $extraStyle .= '.scs-buienradar-pointer { width: '.$DotSize.'px !important; }'."\r\n";
    $extraStyle .= '.scs-buienradar-pointer { height: '.$DotSize.'px !important; }'."\r\n";
    $extraStyle .= '.scs-buienradar-pointer { top: calc(50% - '.$halfSize.'px) !important; }'."\r\n";
    $extraStyle .= '.scs-buienradar-pointer { left: calc(50% - '.$halfSize.'px) !important; }'."\r\n";
    // Adding extra style specific for the dot and not for the image
    $extraStyle .= '.scs-buienradar-pointer { box-shadow: 3px 3px 5px 0px #000000; }'."\r\n";
    $extraStyle .= '.scs-buienradar-pointer { border-radius: 100%; }'."\r\n";
    
    // Adding style tag to the top of the HTML document for better support by browsers
    $stylelink = '<style>'."\r\n";
    $stylelink .= '/* Styling for Scorpion Buienradar module */'."\r\n";
    $stylelink .= $extraStyle;
    $stylelink .= '\r\n';
    $stylelink .= '</style>';
    $document->addCustomTag($stylelink);
} elseif($ShowDotOrImage == '2') {
    // If no slash is at the first character of the image URL add one
    // Bugfix for Joomla rendering
    if($IconFile[0] !== '/') { $IconFile = $baseURL.'/media/mod_scorpion_buienradar/icons/'.$IconFile; };

    // We create extra styling to overrule the values in the css files
    $halfWidth = ((int)$IconWidth) / 2;
    $halfHeight = ((int)$IconHeight) / 2;
    $extraStyle = '.scs-buienradar-pointer { background-color: transparent !important; }'."\r\n";
    $extraStyle .= '.scs-buienradar-pointer { background-image: url('.$IconFile.'); }'."\r\n";
    $extraStyle .= '.scs-buienradar-pointer { width: '.$IconWidth.'px !important; }'."\r\n";
    $extraStyle .= '.scs-buienradar-pointer { height: '.$IconHeight.'px !important; }'."\r\n";
    $extraStyle .= '.scs-buienradar-pointer { left: calc(50% - '.$halfWidth.'px) !important; }'."\r\n";
    $extraStyle .= '.scs-buienradar-pointer { top: calc(50% - '.$halfHeight.'px) !important; }'."\r\n";
    
    // Adding style tag to the top of the HTML document for better support by browsers
    $stylelink = '<style>'."\r\n";
    $stylelink .= '/* Styling for Scorpion Buienradar module */'."\r\n";
    $stylelink .= $extraStyle;
    $stylelink .= '\r\n';
    $stylelink .= '</style>';
    $document->addCustomTag($stylelink);
}

// Now we set the HTML-code that needs to be implemented for this video module
$htmlCode = "\r\n".'<!-- Scorpion Buienradar - BEGIN -->'."\r\n";
$htmlCode .= '<div class="scs-buienradar-wrapper">'."\r\n";

// We display the position if needed
if($LocationPosition == '1') {
    $htmlCode .= '<div style="width: 100%; text-align: '. $LocationAlignment .'" class="scs-buienradar-location">'."\r\n";
    $htmlCode .= '  <span class="scs-buienradar-location-tekst">'.$LocationText.'</span>'."\r\n";
    $htmlCode .= '</div>'."\r\n";
}

$htmlCode .= '<div class="scs-buienradar" width="100%" align="center" >'."\r\n";
// The following part needs to be split for JED checker reasons
$htmlCode .= '  <if' ;
$htmlCode .= 'rame class="scs-buienradar-iframe" title="Scorpion Buienradar Module" width="'.$Breedte.'" height="'.$Hoogte.'" ' ;
$htmlCode .= 'marginheight="0" marginwidth="0" frameborder="0" scrolling="no" ';
$htmlCode .= 'src="https://gadgets.buienradar.nl/gadget/zoommap?lat='.$Latitude.'&x=1&y=1&lng='.$Longitude ;
$htmlCode .= '&overname=2&zoom='.$Zoom;
$htmlCode .= '&naam='.$Plaats;
$htmlCode .= '&size='.$Kaartgrootte;
$htmlCode .= '&voor='.$Tijdsweergave;
$htmlCode .= '"></iframe>'."\r\n";

if($ShowDotOrImage == '1' || $ShowDotOrImage == '2') {
    $hoverTitle = empty($LocationText) ? '' : ' title="' . $LocationText . '"';
    $htmlCode .= '  <div class="scs-buienradar-pointer"' . $hoverTitle . '></div>'."\r\n";
}

$htmlCode .= '</div>'."\r\n";
$htmlCode .= '</div>'."\r\n";

if($LocationPosition == '2') {
    $htmlCode .= '<div style="width: 100%; text-align: '. $LocationAlignment .'" class="scs-buienradar-location">'."\r\n";
    $htmlCode .= '  <span class="scs-buienradar-location-tekst">'.$LocationText.'</span>'."\r\n";
    $htmlCode .= '</div>'."\r\n";
}
$htmlCode .= '<!-- Scorpion Buienradar - END -->'."\r\n";

// Add all the generated HTML code to the module
echo $htmlCode;

?>
